import requestQueue from "./resQueue";

const { createMapKey, queue } = requestQueue;

const fetchData = (instance, { url, method, data, config }, loading) => {
  const controller = new AbortController();
  let httpOpts = {
    url,
    method,
    ...config,
    signal: controller.signal,
  };

  // 注册 请求队列
  let key = createMapKey(method, url, data);
  queue.set(key, controller);

  if (["get", "delete"].includes(method)) {
    httpOpts = { ...httpOpts, params: data };
  }

  if (["patch", "put", "post"].includes(method)) {
    httpOpts = { ...httpOpts, data };
  }

  return new Promise((resolve, rejects) => {
    config?.loading && loading?.show();
    instance(httpOpts)
      .then((res) => resolve(res.data))
      .catch((err) => rejects(err))
      .finally(() => {
        // 每次请求完要对Resqueue 删除
        queue.has(key) && queue.delete(key);
        // 如果有load show 需要关闭
        config?.loading && loading?.hide();
      });
  });
};

export default fetchData;
